Set the properties of the eye-tracker that was used in recording the data
Source:R/tracker_properties_set.R
tracker_properties_set.RdThis function is used to specify the properties of the eye-tracker used to record the data. Users can update one or more parameters. Unnamed parameters retain previous values. If these are not set by the user, then default parameters are set and a warning is issued in every call to relevant functions